==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/j4o/net/SocketWrapper.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System.Net.Sockets;
using NativeSocket=System.Net.Sockets.Socket;

namespace j4o.net
{
	public class SocketWrapper
	{
		protected NativeSocket _delegate;

		protected virtual void Initialize(NativeSocket socket)
		{
			_delegate = socket;
		}

		public void setSoTimeout(int timeout)
		{
            // Socket timeouts have turned out to be a bad option on all supported
            // .NET platforms. If timeouts are turned on, the waiting message loop
            // will run into IoExceptions, causing a CPU load of 100%. 

            // All test cases work fine without socket timeouts on the server.


//			_delegate.SetSocketOption(SocketOptionLevel.Socket, SocketOptionName.ReceiveTimeout, timeout);
//			_delegate.SetSocketOption(SocketOptionLevel.Socket, SocketOptionName.SendTimeout, timeout);
		}

		public void close()
		{
			_delegate.Close();
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/j4o/net/SocketWrapper.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System.Net.Sockets;
using NativeSocket=System.Net.Sockets.Socket;

namespace j4o.net
{
	public class SocketWrapper
	{
		protected NativeSocket _delegate;

		protected virtual void Initialize(NativeSocket socket)
		{
			_delegate = socket;
		}

		public void SetSoTimeout(int timeout)
		{
            // Socket timeouts have turned out to be a bad option on all supported
            // .NET platforms. If timeouts are turned on, the waiting message loop
            // will run into IoExceptions, causing a CPU load of 100%. 

            // All test cases work fine without socket timeouts on the server.

//			_delegate.SetSocketOption(SocketOptionLevel.Socket, SocketOptionName.ReceiveTimeout, timeout);
//			_delegate.SetSocketOption(SocketOptionLevel.Socket, SocketOptionName.SendTimeout, timeout);
		}

		public void Close()
		{
			_delegate.Close();
		}

        public bool IsConnected() 
        {
            return _delegate.Connected;
        }

	}
}
